@@ -725,7 +725,7 @@ int _mutt_enter_string (char *buf, size_t buflen, int col,
                  !memcmp (tempbuf, state->wbuf, state->lastchar * sizeof (wchar_t))))
 	    {
 	      _mutt_select_file (buf, buflen,
-				 ((flags & MUTT_MAILBOX) ? MUTT_SEL_FOLDER : 0) | (multiple ? MUTT_SEL_MULTI : 0),
+				 ((flags & MUTT_MAILBOX) ? MUTT_SEL_MAILBOX : 0) | (multiple ? MUTT_SEL_MULTI : 0),
 				 files, numfiles);
 	      if (!multiple && *buf)
 	      {
